@@ -51,13 +51,14 @@ def E(expr,color = "red"):
         DataRealSymbolList.append([element[0],sy.symbols("("+word+")")])
     else:
       #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
-      DataRealSymbolList.append([element[0],word])
+      DataRealSymbolList.append([element[0],element[0]])
   #display(DataRealSymbolList)
   D(expr)
 
   if isinstance(expr,sy.core.relational.Equality):
+    
+    D(expr.subs(DataRealSymbolList))
     D(expr.subs(DatosList))
-    D((expr.subs(DatosList)).subs(DataRealSymbolList))
   
   if isinstance(expr,list):
     D([expr[0],expr[1].subs(DatosList)])
